@@ -12,21 +12,23 @@ if($m_nRight <= 1) {
       my $wrong_captcha_text = translate("wrong_captcha_text");
       use Authen::Captcha;
       my $captcha = Authen::Captcha->new(
-	data_folder   => "$m_hrSettings->{cgi}{bin}/config/",
-	output_folder => "$m_hrSettings->{cgi}{DocumentRoot}/images",
+	data_folder   => "config/",
+	output_folder => "../images",
 	expire        => 300);
       my $md5sum = $captcha->generate_code(3);
       $authen = qq|<input size="5" type="hidden" name="md5" value="$md5sum"/>
-      <label for="captcha"><img src="/images/$md5sum.png" border="0" style="margin:0.2em;"/></label>
+      <label for="captcha"><img src="images/$md5sum.png" border="0" style="margin:0.2em;"/></label>
       <input autocomplete="off" onkeypress="if(enter(event))return false;" type="text" size="5" data-regexp="|.'/^.{3}$/'.qq|" data-error="$wrong_captcha_text" data-right="$right_captcha_text"  name="captcha"/>|;
     });
-    warn $@ if $@;
+    $m_sContent .= $@ if $@;
+    
     $m_sContent .= div({align => 'center'}, translate('Codenotcheckedfileerror')) if $m_nSkipCaptch eq  0;
     $m_sContent .= div({align => 'center'}, translate('Codenotcheckedfileerror')) if $m_nSkipCaptch eq -1;
     $m_sContent .= div({align => 'center'}, translate('Failednotindatabase'))     if $m_nSkipCaptch eq -2;
     $m_sContent .= div({align => 'center'}, translate('Failedinvalidcode'))       if $m_nSkipCaptch eq -3;
     $m_sContent .= qq(
     <div class="dbForm">
+    <img src="images/logo.png" alt="MySQL-Admin"/>
     <form name="login" id="loginForm" class="dbForm" target="_parent" method="get" name="Login"  onsubmit="submitForm(this,'ShowDatabases','ShowDatabases');return false;">
     <label for="user" class="caption">$name</label>
     <input type="text" id="user" data-regexp=").'/^\w{4,100}$/'.qq(" data-error="$wrong_username_text" data-right="$right_username_text" name="user"/>
