@@ -1,47 +1,47 @@
 $VAR1 = {
-          'mod' => 'n',
-          'scriptAlias' => 'cgi-bin',
-          'actions' => 'cgi-bin//config/actions.pl',
-          'config' => 'cgi-bin//config/settings.pl',
-          'translate' => 'cgi-bin//config/translate.pl',
-          'database' => {
-                          'CurrentPass' => '',
-                          'CurrentDb' => 'LZE',
-                          'CurrentUser' => 'root',
-                          'user' => 'root',
-                          'CurrentHost' => 'localhost',
-                          'name' => 'LZE',
-                          'password' => '',
-                          'host' => 'localhost'
-                        },
+          'version' => '0.83',
+          'uploads' => {
+                         'chmod' => 438,
+                         'maxlength' => 21000000,
+                         'path' => '/var/www/htdocs/download'
+                       },
           'admin' => {
                        'password' => 'testpass',
                        'email' => 'your@email.org'
                      },
-          'uploads' => {
-                         'maxlength' => 21000000,
-                         'path' => '/var/www/htdocs/download',
-                         'chmod' => 438
-                       },
-          'files' => {
-                       'owner' => 'lze',
-                       'group' => 'lze',
-                       'chmod' => '0755'
-                     },
-          'language' => 'en',
-          'session' => 'cgi-bin//config/session.pl',
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'database' => {
+                          'host' => 'localhost',
+                          'CurrentPass' => '',
+                          'password' => '',
+                          'CurrentUser' => 'root',
+                          'CurrentDb' => 'LZE',
+                          'name' => 'LZE',
+                          'user' => 'root',
+                          'CurrentHost' => 'localhost'
+                        },
           'floodtime' => 10,
+          'session' => '/var/www/cgi-bin/config/session.pl',
           'cgi' => {
-                     'cookiePath' => '/',
-                     'expires' => '+1y',
-                     'alias' => 'cgi-bin',
-                     'title' => 'MySQL::Admin',
                      'serverName' => 'localhost',
-                     'DocumentRoot' => 'htdocs/',
+                     'alias' => 'perl',
                      'style' => 'mysql',
-                     'bin' => 'cgi-bin/'
+                     'title' => 'MySQL::Admin',
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'expires' => '+1y',
+                     'bin' => '/var/www/cgi-bin',
+                     'cookiePath' => '/'
                    },
-          'version' => '0.82',
-          'apacheconfig' => 'n'
+          'mod' => 0,
+          'language' => 'en',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'files' => {
+                       'chmod' => '0755',
+                       'group' => 'lze',
+                       'owner' => 'lze'
+                     },
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'scriptAlias' => 'perl'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
