@@ -20,13 +20,12 @@ use ModPerl::Util        ();    #for CORE::GLOBAL::exit
 use Apache2::RequestRec  ();
 use Apache2::RequestIO   ();
 use Apache2::RequestUtil ();
-use Apache2::ServerRec   ();
 use Apache2::ServerUtil  ();
 use Apache2::Connection  ();
 use Apache2::Log         ();
 use APR::Table           ();
 use ModPerl::Registry    ();
-use Apache2::Const -compile => ':common';
-use APR::Const -compile     => ':common';
-
+use APR::Const    -compile => qw(:error SUCCESS);
+use Apache2::Const -compile => qw(:log);
+use Apache2::ServerRec qw(warn);
 1;
